@@ -45,7 +45,7 @@ Code::TidyAll::Plugin::YAPF - Code::TidyAll plugin to tidy Python code via yapf
 
 =head1 VERSION
 
-version 0.000001
+version 0.000002
 
 =head1 SYNOPSIS
 
@@ -54,7 +54,7 @@ This module requires L<Code::TidyAll>.
    In the .tidyallrc configuration file add:
 
    [YAPF]
-   select = static/**/*.py
+   select = **/*.py
 
 Then run
 
@@ -64,6 +64,8 @@ Then run
 
 Runs C<yapf> on Python files.
 
+=over
+
 =item argv
 
 Arguments to pass to C<yapf>.
